#
# spec file for package python-croniter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-croniter
Version:        5.0.1
Release:        1.2
Summary:        Python iterators for datetime objects with cron-like format
License:        MIT
URL:            https://github.com/kiorky/croniter
Source:         https://files.pythonhosted.org/packages/source/c/croniter/croniter-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 3.0.3}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tzlocal}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-python-dateutil
BuildArch:      noarch
%python_subpackages

%description
croniter provides iterators for datetime object with cron-like format.

%prep
%setup -q -n croniter-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest src

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/croniter
%{python_sitelib}/croniter-%{version}.dist-info

%changelog
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Community wanted: Reintroduce 7 as DayOfWeek in deviation
    from standard cron (#90). [kiorky]
  * Remove DayOfWeek alias 7 to DayOfWeek 0 to stick to standard
    cron (#90). [kiorky]
  * Fix DOW ranges calculations when lastday is a Sunday.
    [kiorky]
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.4:
  * Fix overflow on 32bits systems (#87) [kiorky]
  * Fix python2 testing (related to #93) [kiorky]
  * Modernize packaging. Special thanks to Aarni Koskela (akx)
    for all the inputs. [kiorky, akx]
* Wed Oct  9 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.3:
  * Fix start_time not respected in
    get_next/get_prev/all_next/all_prev (#86) [hesstobi, kiorky]
  * Add an update_current argument to
    get_next/get_prev/all_next/all_prev to facilitate writing of
    some downstream code, see #83. [kiorky]
  * Support for year field [zhouyizhen, kiorky]
  * Better support for 6 fields (second), and 7 fields crons
    [zhouyizhen, kiorky]
  * Better fix hashed expressions omitting some entries (#82,
    [#42], #30) fix is retained over #42 initial fix [zhouyizhen,
    kiorky]
  * Ensure match return false when not time available (#81)
* Fri Sep 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 2.0.7:
  * fix doc
- update to 2.0.6:
  * Implement second_at_beginning [zhouyizhen, kiorky]
  * Support question mark as wildcard [zhouyizhen, kiorky]
  * Support to start a cron from a reference start time [mghextreme, kiorky]
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.5:
  * No changes, fix lint
  * Support hashid strings in is_valid
  * Avoid over-optimization in crontab expansions
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.3:
  * Add match_range function [salitaba]
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * fix leap year (29 days in February) [zed2015]
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Fix release issue
  * Add Python 3.12 support
  * Make major release instructions
* Thu Aug 31 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.4.1:
  * Make a retrocompatible version of 1.4.0 change about supporting
    VIXIECRON bug.
  * Added "implement_cron_bug" flag to make the cron parser compatible
    with a bug in Vixie/ISC Cron.
- Switch to pyproject macros.
- Actually drop future requirement.
- Stop using greedy globs in %%files.
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.15:
  * Fix hashed expressions omitting some entries
  * Enhance .match() precision for 6 position expressions
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.14:
  * Add check for range begin/end
  * restore py2 compat
  * Do not expose `i` into global namespace
  * Fix DOW hash parsing [kiorky]
  * better error handling on py3 [kiorky]
  * Add Python 3.11 support and move docs files to main folder
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- use https for urls
* Tue Sep 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.3.7:
  * fix tests
  * Fix croniter_range infinite loop [Shachar Snapiri <ssnapiri@paloaltonetworks.com>]
- Update to v1.3.5:
  * Add Python 3.10 support [eelkevdbos]
- Update to v1.3.4:
  * Really fix compat for tests under py27 [kiorky]
- Update to v1.3.3:
  * Fix compat for tests under py27 [kiorky]
- Update to v1.3.2:
  * Fix #12: regressions with set_current [kiorky, agateblue]
- Update to v1.3.1:
  * Restore compat with python2 [kiorky]
- Update to v1.3.0:
  * Add a way to make next() easier to use. This fixes #11 [kiorky]
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Enforce validation for day=1. Before this release we used to support day=0
    and it was silently glided to day=1 to support having both day in day in
    4th field when it came to have 6fields cron forms (second repeat). It will
    now raises a CroniterBadDateError.
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Enforce validation for month=1. Before this release we used to support
    month=0 and it was silently glided to month=1 to support having both day in
    month in 4th field when it came to have 6fields cron forms
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.15:
  * restore py2
  * better type checks
* Thu Jun 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.13:
  * Fix ZeroDivisionError with ``* * R/0 * *``
  * Add support for hashed/random/keyword expressions
  * Review support support for hashed/random/keyword expression and add expanders reactor
  * fix bug: bad case:``0 6 30 3 *``
  * Create ``CroniterUnsupportedSyntaxError`` exception for situations where CRON syntax may be valid but some combinations of features is not supported.
    This *may* impact existing cron expressions in prior releases, because ``0 0 * * 15,sat#1`` was previously allowed but incorrectly handled.
  * Update ``croniter_range()`` to allow an alternate ``croniter`` class to be used.  Helpful when using a custom class derived from croniter.
  * Remove external library ``natsort``.
* Wed Mar 24 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 1.0.9:
  * Remove dependency on future.
* Fri Mar 12 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.8:
  * Update `_expand` to lowercase each component of the expression.
  * Fix _expand to reject int literals with underscores
  * Fix combination of star and invalid expression bugs
  * Security fix: fix overflow when using cron ranges
  * Fix #155: raise CroniterBadCronError when error syntax
  * Fix match when datetime has microseconds
  * Added Python 3.8 and 3.9 support
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.36:
- Updated docs section regarding ``max_years_between_matches`` to be more shorter and hopefully more relevant.
- Add a new initialization parameter ``max_years_between_matches`` to support finding the next/previous date beyond the default 1 year window, if so desired.  Updated README to include additional notes and example of this usage.  Fixes #145.
- The ``croniter_range()`` function was updated to automatically determines the appropriate ``max_years_between_matches`` value, this preventing handling of the ``CroniterBadDateError`` exception.
- Updated exception handling classes:  ``CroniterBadDateError`` now only
  applies during date finding operations (next/prev), and all parsing errors can now be caught using ``CroniterBadCronError``.  The ``CroniterNotAlphaError`` exception is now a subclass of ``CroniterBadCronError``.  A brief description of each exception class was added as an inline docstring.
- Updated iterable interfaces to replace the ``CroniterBadDateError`` with ``StopIteration`` if (and only if) the ``max_years_between_matches`` argument is provided.  The rationale here is that if the user has specified the max tolerance between matches, then there's no need to further inform them of no additional matches.  Just stop the iteration.  This also keeps backwards compatibility.
- Minor docs update
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.34:
  - Feat croniter_range(start, stop, cron)
  - Optimization for poorly written cron expression
  - Make dateutil tz support more official
  - Feat/support for day or
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.32:
  - document seconds repeats, fixes #122
  - Implement match method, fixes #54
  - Adding tests for #127 (test more DSTs and croniter behavior around)
  - Changed lag_hours comparison to absolute to manage dst boundary when getting previous
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.31:
  - Fix get_next() when start_time less then 1s before next instant
* Thu May 23 2019 pgajdos@suse.com
- version update to 0.3.30
  * credits
  * history stripping (security)
  * Handle -Sun notation
  * Handle invalid ranges correctly
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.28:
  * Update credits
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.27:
  * Handle -Sun notation
  * Handle invalid ranges correctly
  * Pypi hygiene
  * fix get_next while perserving the fix of get_prev
  * Don't count previous minute if now is dynamic If the code is triggered from 5-asterisk based cron get_prev based on datetime.now() is expected to return current cron iteration and not previous execution.
* Wed Oct 17 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary.
* Wed Oct 17 2018 sjamgade@suse.com
- update to 0.3.20
  - (tag: 0.3.20) Preparing release 0.3.20
  - pep8
  - Fix sao paulo timezone test.
  - remove outdated comment
  - correctly handle DST changes
  - Merge pull request #89 from kiorky/master
  - Back to development: 0.3.20
  - (tag: 0.3.19) Preparing release 0.3.19
  - fix #87: backward dst changes
  - Merge pull request #88 from kiorky/master
  - Back to development: 0.3.19
  - (tag: 0.3.18) Preparing release 0.3.18
  - Merge pull request #18 from taichino/master
  - Merge pull request #86 from otherpirate/master
  - Adding is_valid class method to readme
  - Adding class method is_valid to validate cron syntax
  - Creating base croniter error
  - Merge pull request #85 from kiorky/master
  - Back to development: 0.3.18
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.3.17:
  - DOW occurence sharp style support.
  - Better test suite
  - DST support
  - fix bug around multiple conditions and range_val in
    _get_prev_nearest_diff.
  - issue #69: added day_or option to change behavior when day-of-month and
    day-of-week is given
  - `Real fix for #34
  - `Modernize test infra
  - `Release as a universal wheel
  - `Raise ValueError on negative numbers
  - `Compare types using "issubclass" instead of exact match
  - `Implement step cron with a variable base
- convert to singlespec
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.3.12
* Wed Apr 13 2016 dmueller@suse.com
- switch to python-python-dateutil
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 0.3.5:
  * support for 'l' (last day of month)
* Fri Mar  7 2014 speilicke@suse.com
- Package docs/LICENSE
* Fri Mar  7 2014 speilicke@suse.com
- Fix requirement on python-dateutil (not python-python-dateutil as upstream)
* Fri Mar  7 2014 speilicke@suse.com
- Initial version
